# Project Description
- Everytime we want to create a project in python we need to create a virtual environment, and the command line interface (CLI) might be complicated and can cause confusion, sometimes it might cause frustration and time consuming when you have to navigate to a long folder path or mistype something and then you have to retype everything again.



## Release Note
- 0.0.1: Beta version, buggy, just can use the first option only.
- 0.0.2: Still buggy but now can use some of the second option.
- 0.0.4: Update the code structure and checking system.
